@@ -3,14 +3,14 @@ from .api_key import ApiKey
 
 
 """
-contentful.api_keys_proxy
-~~~~~~~~~~~~~~~~~~~~~~~
+contentful_management.api_keys_proxy
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This module implements the ApiKeysProxy class.
 
-API Reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/api-keys
+API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/api-keys
 
-:copyright: (c) 2017 by Contentful GmbH.
+:copyright: (c) 2018 by Contentful GmbH.
 :license: MIT, see LICENSE for more details.
 """
 
@@ -21,6 +21,8 @@ class ApiKeysProxy(ClientProxy):
         return ApiKey
 
     def create(self, attributes=None, **kwargs):
-        """Creates an API Key with given attributes."""
+        """
+        Creates an API key with given attributes.
+        """
 
         return super(ApiKeysProxy, self).create(None, attributes)
